from poco.drivers.android.uiautomation import AndroidUiautomationPoco
from poco.utils import six
from airobots.core.api import ST, screen_attach
from typing import List, Union
import allure
import os


class AndroidUiautomation(AndroidUiautomationPoco):
    def __init__(self, device=None, using_proxy=True, force_restart=False, use_airtest_input=False, **options):
        super(AndroidUiautomation, self).__init__(device=device, using_proxy=using_proxy, force_restart=force_restart, use_airtest_input=use_airtest_input, **options)

    @allure.step
    def click(self, pos: Union[float, float]):
        ret = super(AndroidUiautomation, self).click(pos)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def swipe(self, p1: Union[float, float], p2: Union[float, float]=None, direction: Union[float, float]=None, duration: float=2.0):
        ret = super(AndroidUiautomation, self).swipe(p1=p1, p2=p2, direction=direction, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def long_click(self, pos: Union[float, float], duration: float=2.0):
        ret = super(AndroidUiautomation, self).long_click(pos=pos, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def scroll(self, direction: Union[List[float], str], percent: float=0.6, duration: float=2.0):
        ret = super(AndroidUiautomation, self).scroll(direction=direction, percent=percent, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def pinch(self, direction: str='in', percent: float=0.6, duration: float=2.0, dead_zone: float=0.1):
        ret = super(AndroidUiautomation, self).pinch(direction=direction, percent=percent, duration=duration, dead_zone=dead_zone)
        if self.screenshot_each_action: screen_attach()
        return ret



import argparse
import os
import sys
import pytest
from airobots import __description__, __version__
from airhttprunner.cli import main_run
from .core.settings import ST


def main():
    """ API test: parse command line options and run commands.
    """
    parser = argparse.ArgumentParser(description=__description__)
    parser.add_argument(
        "-v", "--version", dest="version", action="store_true", help="show version"
    )
    parser.add_argument(
        "-t", "--type", dest="type", required=True, default='api', choices=['api', 'web', 'ios', 'android'], help="test type, choices: api, web, ios, android"
    )
    parser.add_argument(
        "-b", "--browser", dest="browser", default='Chrome', choices=['Firefox', 'Chrome', 'Ie', 'Opera', 'Safari', 'PhantomJS'], help="test browser, choices: Firefox, Chrome, Ie, Opera, Safari, PhantomJS"
    )
    parser.add_argument(
        "-r", "--remote-url", dest="remote_url", default=None, help="gui test's remote url, eg. http://localhost:4444/wd/hub"
    )
    
    if len(sys.argv) < 2:
        # httprunner
        parser.print_help()
        sys.exit(0)

    extra_args = []
    if len(sys.argv) >= 2:
        if sys.argv[1] in ["-v", "--version"]:
            print(f"{__version__}")
            sys.exit(0)
        elif sys.argv[1] in ["-h", "--help"]:
            parser.print_help()
            sys.exit(0)
        else:
            args, extra_args = parser.parse_known_args()
    else:
        args = parser.parse_args()

    if args.version:
        print(f"{__version__}")
        sys.exit(0)

    if args.type == "api":
        sys.exit(main_run(extra_args))
    elif args.type in ['web', 'ios', 'android']:
        ST.BROWSER = args.browser or ST.BROWSER
        ST.REMOTE_URL = args.remote_url or ST.REMOTE_URL
        if not os.path.exists(ST.LOG_DIR): os.makedirs(ST.LOG_DIR)
        sys.exit(pytest.main(extra_args))
    else:
        parser.print_help()


if __name__ == "__main__":
    main()


# -*- coding: utf-8 -*-
"""
This module contains the Airtest Core APIs.
"""
import os

from airtest.core.cv import Template, loop_find
from airtest.core.error import TargetNotFoundError
from .settings import ST
from airtest.utils.compat import script_log_dir
from airtest.core.helper import (G, delay_after_operation, import_device_cls,
                                 logwrap, set_logdir, using, log)

from airtest.core.api import init_device, connect_device, device, set_current, auto_setup
from airtest.core.api import shell as air_shell
from airtest.core.api import start_app as air_start_app
from airtest.core.api import stop_app as air_stop_app
from airtest.core.api import clear_app as air_clear_app
from airtest.core.api import install as air_install
from airtest.core.api import uninstall as air_uninstall
from airtest.core.api import snapshot as air_snapshot
from airtest.core.api import wake as air_wake
from airtest.core.api import home as air_home
from airtest.core.api import touch as air_touch
from airtest.core.api import double_click as air_double_click
from airtest.core.api import swipe as air_swipe
from airtest.core.api import pinch as air_pinch
from airtest.core.api import keyevent as air_keyevent
from airtest.core.api import text as air_text
from airtest.core.api import sleep as air_sleep
from airtest.core.api import wait as air_wait
from airtest.core.api import exists as air_exists
from airtest.core.api import find_all as air_find_all
from airtest.core.api import assert_exists as air_assert_exists
from airtest.core.api import assert_not_exists as air_assert_not_exists
from airtest.core.api import assert_equal as air_assert_equal
from airtest.core.api import assert_not_equal as air_assert_not_equal
import allure


def screen_attach():
    screen = air_snapshot()
    if not screen: return
    filepath = os.path.join(ST.LOG_DIR, screen.get('screen'))
    with open(filepath, 'rb') as fp:
        allure.attach(fp.read(), '截图', allure.attachment_type.PNG)

@allure.step
def shell(cmd):
    return air_shell(cmd)


@allure.step
def start_app(package, activity=None):
    air_start_app(package, activity)


@allure.step
def stop_app(package):
    air_stop_app(package)


@allure.step
def clear_app(package):
    air_clear_app(package)


@allure.step
def install(filepath, **kwargs):
    return air_install(filepath, **kwargs)


@allure.step
def uninstall(package):
    return air_uninstall(package)


@allure.step
def snapshot(filename=None, msg="", quality=None, max_size=None):
    return air_snapshot(filename=filename, msg=msg, quality=quality, max_size=max_size)


@allure.step
def wake():
    air_wake()


@allure.step
def home():
    air_home()


@allure.step
def touch(v, times=1, **kwargs):
    pos = air_touch(v, times=times, **kwargs)
    screen_attach()
    return pos

click = touch  # click is alias of touch


@allure.step
def double_click(v):
    pos = air_double_click(v)
    screen_attach()
    return pos


@allure.step
def swipe(v1, v2=None, vector=None, **kwargs):
    pos = air_swipe(v1, v2=v2, vector=vector, **kwargs)
    screen_attach()
    return pos


@allure.step
def pinch(in_or_out='in', center=None, percent=0.5):
    air_pinch(in_or_out=in_or_out, center=center, percent=percent)
    screen_attach()


@allure.step
def keyevent(keyname, **kwargs):
    air_keyevent(keyname, **kwargs)


@allure.step
def text(text, enter=True, locator=None, **kwargs):
    air_text(text, enter=enter, locator=locator, **kwargs)
    screen_attach()


@allure.step
def sleep(secs=1.0):
    air_sleep(secs)


@allure.step
def wait(v, timeout=None, interval=0.5, intervalfunc=None):
    return air_wait(v, timeout=timeout, interval=interval, intervalfunc=intervalfunc)


@allure.step
def exists(v):
    return air_exists(v)


@allure.step
def find_all(v):
    return air_find_all(v)


"""
Assertions
"""


@allure.step
def assert_exists(v, msg=""):
    return air_assert_exists(v, msg=msg)


@allure.step
def assert_not_exists(v, msg=""):
    return air_assert_not_exists(v, msg=msg)


@allure.step
def assert_equal(first, second, msg=""):
    return air_assert_equal(first, second, msg=msg)

@allure.step
def assert_not_equal(first, second, msg=""):
    return air_assert_not_equal(first, second, msg=msg)


from poco.drivers.ios import iosPoco
from poco.utils import six
from airobots.core.api import ST, screen_attach, connect_device, device as current_device
from typing import List, Union
import allure
import os


class IOSUiautomation(iosPoco):
    def __init__(self, device=None, screenshot_each_action=True, **kwargs):
        self.screenshot_each_action = screenshot_each_action
        device = device or current_device()
        if not device:
            device = connect_device("iOS:///127.0.0.1:8100")
        self.device = device
        super(IOSUiautomation, self).__init__(device=device, **kwargs)

    @allure.step
    def click(self, pos: Union[float, float]):
        ret = super(IOSUiautomation, self).click(pos)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def swipe(self, p1: Union[float, float], p2: Union[float, float]=None, direction: Union[float, float]=None, duration: float=2.0):
        ret = super(IOSUiautomation, self).swipe(p1=p1, p2=p2, direction=direction, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def long_click(self, pos: Union[float, float], duration: float=2.0):
        ret = super(IOSUiautomation, self).long_click(pos=pos, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def scroll(self, direction: Union[List[float], str], percent: float=0.6, duration: float=2.0):
        ret = super(IOSUiautomation, self).scroll(direction=direction, percent=percent, duration=duration)
        if self.screenshot_each_action: screen_attach()
        return ret

    @allure.step
    def pinch(self, direction: str='in', percent: float=0.6, duration: float=2.0, dead_zone: float=0.1):
        ret = super(IOSUiautomation, self).pinch(direction=direction, percent=percent, duration=duration, dead_zone=dead_zone)
        if self.screenshot_each_action: screen_attach()
        return ret



# coding=utf8

import sys
import pathlib
from setuptools import setup, find_packages
from src.airobots import __version__

reqs = ["selenium", "airtest", "airtest_selenium", "pocoui","requests","pymysql","pymongo","pytest", "pm2case", "ms2case","pytest-selenium", "pytest-rerunfailures","pynput","pywinio","airhttprunner","airhttprunner[allure]","locust", "airhttprunner[locust]", "airhttprunner[upload]","allure-pytest", "pytest-repeat","AirobotLibrary"]
if sys.platform == "win32":
    reqs.append('pywin32')
    reqs.append('pyautogui')

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='airobots',
    version=__version__,
    author='贝克街的捉虫师',
    author_email='forpeng@foxmail.com',
    description='UI Test Automation Framework for Games and Apps on Android/iOS/Windows/Linux/Web',
    long_description=long_description,  # Optional
    long_description_content_type='text/markdown',  # Optional (see note above)
    url='https://github.com/BSTester/Airobots',
    license='Apache License 2.0',
    keywords=['automation', 'automated-test', 'game', 'android', 'ios', 'windows', 'linux', 'web'],
    package_dir={'': 'src'},  # Optional
    packages=find_packages(where='src'),
    python_requires='>=3.5, <4',
    install_requires=reqs,
    entry_points="""
    [console_scripts]
    airobots = airobots.__main__:main
    """,
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
    ],
    project_urls={  # Optional
        # 'Bug Reports': 'https://github.com/pypa/sampleproject/issues',
        # 'Funding': 'https://donate.pypi.org',
        # 'Say Thanks!': 'http://saythanks.io/to/example',
        'Source': 'https://github.com/BSTester/Airobots',
    },
)
